Changelog
=========

0.9.3 (2018-06-19)
------------------
- aiobravado doesn't work with the latest bravado-asyncio version, let's add a restriction to setup.py - PR #6.

0.9.2 (2018-02-08)
------------------
- Don't ship our own HTTP client, use bravado-asyncio - PR #2.

0.9.1 (2018-01-11)
------------------
- bravado version: 9.2.2
- Fix unmarshalling of non-JSON/msgpack responses - PR #1.

0.9.0 (2017-11-17)
------------------
- Initial release, based on the source code of bravado 9.2.0.
